/*
 * Copyright (C) 2013-2014 Dominik Schürmann <dominik@dominikschuermann.de>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.sufficientlysecure.keychain.remote.ui;

import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.content.pm.PackageManager.NameNotFoundException;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import org.spongycastle.util.encoders.Hex;
import org.sufficientlysecure.keychain.Constants;
import org.sufficientlysecure.keychain.R;
import org.sufficientlysecure.keychain.remote.AppSettings;
import org.sufficientlysecure.keychain.util.Log;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

public class AppSettingsHeaderFragment extends Fragment {

    // model
    private AppSettings mAppSettings;

    // view
    private TextView mAppNameView;
    private ImageView mAppIconView;
    private TextView mPackageName;
    private TextView mPackageCertificate;

    public AppSettings getAppSettings() {
        return mAppSettings;
    }

    public void setAppSettings(AppSettings appSettings) {
        this.mAppSettings = appSettings;
        updateView(appSettings);
    }

    /**
     * Inflate the layout for this fragment
     */
    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View view = inflater.inflate(R.layout.api_app_settings_fragment, container, false);
        mAppNameView = (TextView) view.findViewById(R.id.api_app_settings_app_name);
        mAppIconView = (ImageView) view.findViewById(R.id.api_app_settings_app_icon);
        mPackageName = (TextView) view.findViewById(R.id.api_app_settings_package_name);
        mPackageCertificate = (TextView) view.findViewById(R.id.api_app_settings_package_certificate);
        return view;
    }

    private void updateView(AppSettings appSettings) {
        // get application name and icon from package manager
        String appName;
        Drawable appIcon = null;
        PackageManager pm = getActivity().getApplicationContext().getPackageManager();
        try {
            ApplicationInfo ai = pm.getApplicationInfo(appSettings.getPackageName(), 0);

            appName = (String) pm.getApplicationLabel(ai);
            appIcon = pm.getApplicationIcon(ai);
        } catch (NameNotFoundException e) {
            // fallback
            appName = appSettings.getPackageName();
        }
        mAppNameView.setText(appName);
        mAppIconView.setImageDrawable(appIcon);

        // advanced info: package name
        mPackageName.setText(appSettings.getPackageName());

        // advanced info: package signature SHA-256
        try {
            MessageDigest md = MessageDigest.getInstance("SHA-256");
            md.update(appSettings.getPackageCertificate());
            byte[] digest = md.digest();
            String signature = new String(Hex.encode(digest));

            mPackageCertificate.setText(signature);
        } catch (NoSuchAlgorithmException e) {
            Log.e(Constants.TAG, "Should not happen!", e);
        }
    }


}
